@@ -37,27 +37,3 @@ class NoteRepository(DescriptionRepository[Note]):
             return Note.fromText(id, text)
         else:
             return Note(NoteMetadata(id), id)
-
-
-if __name__ == "__main__":
-    text = NoteMetadata("name").toText()
-    print(text)
-    print(NoteMetadata.fromText(text))
-
-    manager = NoteRepository(pathlib.Path(
-        __file__).parent.parent.parent.parent.parent.joinpath("temp").joinpath("notes"))
-
-    del manager["a"]
-
-    a = manager.create("a")
-    a.content = "# abc\n"
-    manager.update(a)
-
-    print(a)
-    import time
-
-    time.sleep(1)
-
-    print(manager["a"])
-
-    print(list(manager))
